@@ -30,22 +30,23 @@ WorkingTree.open(dir).
 """
 
 
-from bisect import bisect_left
-import breezy
-from collections import deque
 import errno
-from io import BytesIO
 import itertools
 import operator
 import os
 import stat
 import sys
+from bisect import bisect_left
+from collections import deque
+from io import BytesIO
 
+import breezy
+
+from .. import lazy_import
 # Explicitly import breezy.bzrdir so that the BzrProber
 # is guaranteed to be registered.
 from . import bzrdir
 
-from .. import lazy_import
 lazy_import.lazy_import(globals(), """
 import contextlib
 from breezy import (
@@ -66,31 +67,16 @@ from breezy.bzr import (
     )
 """)
 
-from .. import (
-    errors,
-    osutils,
-    revision as _mod_revision,
-    transport as _mod_transport,
-    )
+from .. import errors, osutils
+from .. import revision as _mod_revision
+from .. import transport as _mod_transport
 from ..controldir import ControlDir
 from ..lock import LogicalLockResult
-from .inventorytree import InventoryRevisionTree, MutableInventoryTree
 from ..trace import mutter, note
-from ..tree import (
-    get_canonical_path,
-    MissingNestedTree,
-    TreeDirectory,
-    TreeEntry,
-    TreeFile,
-    TreeLink,
-    TreeReference,
-    )
-from ..workingtree import (
-    WorkingTree,
-    WorkingTreeFormat,
-    format_registry,
-    )
-
+from ..tree import (MissingNestedTree, TreeDirectory, TreeEntry, TreeFile,
+                    TreeLink, TreeReference, get_canonical_path)
+from ..workingtree import WorkingTree, WorkingTreeFormat, format_registry
+from .inventorytree import InventoryRevisionTree, MutableInventoryTree
 
 MERGE_MODIFIED_HEADER_1 = b"BZR merge-modified list format 1"
 # TODO: Modifying the conflict objects or their type is currently nearly
@@ -286,11 +272,8 @@ class InventoryWorkingTree(WorkingTree, MutableInventoryTree):
     # XXX: This method should be deprecated in favour of taking in a proper
     # new Inventory object.
     def set_inventory(self, new_inventory_list):
-        from .inventory import (
-            Inventory,
-            InventoryDirectory,
-            InventoryFile,
-            InventoryLink)
+        from .inventory import (Inventory, InventoryDirectory, InventoryFile,
+                                InventoryLink)
         with self.lock_tree_write():
             inv = Inventory(self.path2id(''))
             for path, file_id, parent, kind in new_inventory_list:
