@@ -18,46 +18,28 @@
 import errno
 import os
 import posixpath
-from stat import S_IEXEC, S_ISREG
 import tempfile
 import time
+from stat import S_IEXEC, S_ISREG
 
-from .mapping import encode_git_path, mode_kind, mode_is_executable, object_mode
-from .tree import GitTree, GitTreeDirectory, GitTreeSymlink, GitTreeFile
-from .mapping import decode_git_path
+from dulwich.index import blob_from_path_and_stat, commit_tree
+from dulwich.objects import Blob
 
-from .. import (
-    annotate,
-    conflicts,
-    errors,
-    multiparent,
-    osutils,
-    revision as _mod_revision,
-    trace,
-    transport as _mod_transport,
-    ui,
-    urlutils,
-    )
+from .. import annotate, conflicts, errors, multiparent, osutils
+from .. import revision as _mod_revision
+from .. import trace
+from .. import transport as _mod_transport
+from .. import ui, urlutils
 from ..i18n import gettext
 from ..mutabletree import MutableTree
+from ..transform import (ROOT_PARENT, FinalPaths, ImmortalLimbo,
+                         MalformedTransform, PreviewTree, ReusingTransform,
+                         TransformRenameFailed, TreeTransform, _FileMover,
+                         _TransformResults, joinpath, unique_add)
 from ..tree import InterTree, TreeChange
-from ..transform import (
-    PreviewTree,
-    TreeTransform,
-    _TransformResults,
-    _FileMover,
-    FinalPaths,
-    joinpath,
-    unique_add,
-    TransformRenameFailed,
-    ImmortalLimbo,
-    ROOT_PARENT,
-    ReusingTransform,
-    MalformedTransform,
-    )
-
-from dulwich.index import commit_tree, blob_from_path_and_stat
-from dulwich.objects import Blob
+from .mapping import (decode_git_path, encode_git_path, mode_is_executable,
+                      mode_kind, object_mode)
+from .tree import GitTree, GitTreeDirectory, GitTreeFile, GitTreeSymlink
 
 
 class TreeTransformBase(TreeTransform):
@@ -754,17 +736,16 @@ class TreeTransformBase(TreeTransform):
         if not raw_conflicts:
             return
         fp = FinalPaths(self)
-        from .workingtree import TextConflict
+        from .workingtree import TextConflict, ContentsConflict
         for c in raw_conflicts:
             if c[0] == 'text conflict':
                 yield TextConflict(fp.get_path(c[1]))
+            elif c[0] == 'contents conflict':
+                yield ContentsConflict(fp.get_path(c[1][0]))
             elif c[0] == 'duplicate':
                 yield TextConflict(fp.get_path(c[2]))
-            elif c[0] == 'contents conflict':
-                yield TextConflict(fp.get_path(c[1][0]))
             elif c[0] == 'missing parent':
-                # TODO(jelmer): This should not make it to here
-                yield TextConflict(fp.get_path(c[2]))
+                pass
             elif c[0] == 'non-directory parent':
                 yield TextConflict(fp.get_path(c[2]))
             elif c[0] == 'deleting parent':
@@ -773,8 +754,6 @@ class TreeTransformBase(TreeTransform):
             elif c[0] == 'parent loop':
                 # TODO(jelmer): This should not make it to here
                 yield TextConflict(fp.get_path(c[2]))
-            elif c[0] == 'path conflict':
-                yield TextConflict(fp.get_path(c[1]))
             else:
                 raise AssertionError('unknown conflict %s' % c[0])
 
