@@ -34,17 +34,13 @@ The plugin also provides the following commands:
 
 # see http://wiki.bazaar.canonical.com/Specs/BranchRegistrationTool
 
-from ... import (
-    branch as _mod_branch,
-    config as _mod_config,
-    lazy_regex,
-    # Since we are a built-in plugin we share the breezy version
-    trace,
-    version_info,  # noqa: F401
-    )
-from ...commands import (
-    plugin_cmds,
-    )
+from ... import \
+    branch as \
+    _mod_branch  # Since we are a built-in plugin we share the breezy version
+from ... import config as _mod_config
+from ... import version_info  # noqa: F401
+from ... import lazy_regex, trace
+from ...commands import plugin_cmds
 from ...directory_service import directories
 from ...help_topics import topic_registry
 
@@ -64,14 +60,6 @@ def _register_directory():
     directories.register_lazy('lp+bzr:', 'breezy.plugins.launchpad.lp_directory',
                               'LaunchpadDirectory',
                               'Bazaar-specific Launchpad directory service',)
-    directories.register_lazy(
-        'debianlp:', 'breezy.plugins.launchpad.lp_directory',
-        'LaunchpadDirectory',
-        'debianlp: shortcut')
-    directories.register_lazy(
-        'ubuntu:', 'breezy.plugins.launchpad.lp_directory',
-        'LaunchpadDirectory',
-        'ubuntu: shortcut')
 
 
 _register_directory()
@@ -119,4 +107,5 @@ topic_registry.register('launchpad',
 
 
 from ...forge import forges
+
 forges.register_lazy("launchpad", __name__ + '.forge', "Launchpad")
