@@ -14,13 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from .. import (
-    errors,
-    mail_client,
-    tests,
-    urlutils,
-    osutils,
-    )
+from .. import errors, mail_client, osutils, tests, urlutils
 
 
 class TestMutt(tests.TestCase):
