@@ -20,22 +20,12 @@ import time
 
 from testtools.matchers import *
 
-from .. import (
-    config,
-    tests,
-    ui as _mod_ui,
-    )
-from ..bzr import (
-    remote,
-    )
-from . import (
-    fixtures,
-    ui_testing,
-    )
+from .. import config, tests
+from .. import ui as _mod_ui
+from ..bzr import remote
 from ..ui import text as _mod_ui_text
-from .testui import (
-    ProgressRecordingUIFactory,
-    )
+from . import fixtures, ui_testing
+from .testui import ProgressRecordingUIFactory
 
 
 class TestUIConfiguration(tests.TestCaseInTempDir):
